==> webkit2gtk_2.51.4.orig.tar.xz: webkitgtk-2.51.4/Source/WebCore/dom/TrustedTypePolicyFactory.h <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#pragma once

#include "ContextDestructionObserver.h"
#include "ScriptWrappable.h"
#include "TrustedTypePolicy.h"
#include <wtf/Forward.h>
#include <wtf/ListHashSet.h>
#include <wtf/RefCounted.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class TrustedHTML;
class TrustedScript;
struct TrustedTypePolicyOptions;
class ScriptExecutionContext;

class TrustedTypePolicyFactory : public ScriptWrappable, public RefCounted<TrustedTypePolicyFactory>, public ContextDestructionObserver {
    WTF_MAKE_TZONE_OR_ISO_ALLOCATED(TrustedTypePolicyFactory);
public:
    static Ref<TrustedTypePolicyFactory> create(ScriptExecutionContext&);
    ~TrustedTypePolicyFactory();

    // ContextDestructionObserver.
    void ref() const final { RefCounted::ref(); }
    void deref() const final { RefCounted::deref(); }

    ExceptionOr<Ref<TrustedTypePolicy>> createPolicy(ScriptExecutionContext&, const String& policyName, const TrustedTypePolicyOptions&);
    bool isHTML(JSC::JSValue) const;
    bool isScript(JSC::JSValue) const;
    bool isScriptURL(JSC::JSValue) const;
    Ref<TrustedHTML> emptyHTML() const;
    Ref<TrustedScript> emptyScript() const;

    String getAttributeType(const String& tagName, const String& attribute, const String& elementNamespace, const String& attributeNamespace) const;
    String getPropertyType(const String& tagName, const String& property, const String& elementNamespace) const;

    RefPtr<TrustedTypePolicy> defaultPolicy() const { return m_defaultPolicy; }
    TrustedTypePolicy* defaultPolicyConcurrently() const { return m_defaultPolicy.get(); }

private:
    TrustedTypePolicyFactory(ScriptExecutionContext&);

    RefPtr<TrustedTypePolicy> m_defaultPolicy;
    ListHashSet<String> m_createdPolicyNames;
};

} // namespace WebCore

==> webkit2gtk_2.51.91.orig.tar.xz: webkitgtk-2.51.91/Source/WebCore/dom/TrustedTypePolicyFactory.h <==
/*
 * Copyright (C) 2024 Igalia S.L. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#pragma once

#include "ContextDestructionObserver.h"
#include "ScriptWrappable.h"
#include "TrustedTypePolicy.h"
#include <wtf/Forward.h>
#include <wtf/ListHashSet.h>
#include <wtf/RefCounted.h>
#include <wtf/RefPtr.h>

namespace WebCore {

class TrustedHTML;
class TrustedScript;
struct TrustedTypePolicyOptions;
class ScriptExecutionContext;

class TrustedTypePolicyFactory : public ScriptWrappable, public RefCounted<TrustedTypePolicyFactory>, public ContextDestructionObserver {
    WTF_MAKE_TZONE_ALLOCATED(TrustedTypePolicyFactory);
public:
    static Ref<TrustedTypePolicyFactory> create(ScriptExecutionContext&);
    ~TrustedTypePolicyFactory();

    // ContextDestructionObserver.
    void ref() const final { RefCounted::ref(); }
    void deref() const final { RefCounted::deref(); }

    ExceptionOr<Ref<TrustedTypePolicy>> createPolicy(ScriptExecutionContext&, const String& policyName, const TrustedTypePolicyOptions&);
    bool isHTML(JSC::JSValue) const;
    bool isScript(JSC::JSValue) const;
    bool isScriptURL(JSC::JSValue) const;
    Ref<TrustedHTML> emptyHTML() const;
    Ref<TrustedScript> emptyScript() const;

    String getAttributeType(const String& tagName, const String& attribute, const String& elementNamespace, const String& attributeNamespace) const;
    String getPropertyType(const String& tagName, const String& property, const String& elementNamespace) const;

    RefPtr<TrustedTypePolicy> defaultPolicy() const { return m_defaultPolicy; }
    TrustedTypePolicy* defaultPolicyConcurrently() const { return m_defaultPolicy.get(); }

private:
    TrustedTypePolicyFactory(ScriptExecutionContext&);

    RefPtr<TrustedTypePolicy> m_defaultPolicy;
    ListHashSet<String> m_createdPolicyNames;
};

} // namespace WebCore
